#version 140

uniform mat4 projectionMatrix;			// projection matrix for the whole scene
uniform mat4 modelViewMatrix;			// model view matrix (view * model)
uniform mat4 textureMatrix;				// matrix that transforms from camera space to light space
										// by first inverting the camera transformation (in world space now),
										// then by transforming to the light by using the light view matrix,
										// then projecting by the light projection matrix
uniform mat4 lightProjectionMatrix;		// projection matrix for the light
uniform mat4 modelMatrix;				// model matrix for light transformation

out vec4 fragShadowMapCoords;			// coordinates into the shadow map (we'll be interpolating them)

in vec3 vertex;
in vec3 normal;

//in vec2 texCoords;

out float fragIntensity;
out vec2 fragTexCoords;

uniform vec3 directionalLight;

void main(void)
{
	// constant light direction
	vec3 ld = directionalLight;
	
	// calculate the position of the vertex
	gl_Position = projectionMatrix * modelViewMatrix * vec4(vertex, 1.0);

	// calculate the shadow map coords
	fragShadowMapCoords = textureMatrix * modelViewMatrix * vec4(vertex, 1.0);
	
	// basic shading
	vec4 N = modelMatrix * vec4(normal, 0.0);
	float NdotL = max(dot(vec3(N.x, N.y, N.z), ld), 0.0);
	
	fragIntensity = NdotL * 0.8 + 0.2;	
	
	//fragTexCoords = texCoords;
}